# Open-DIP

Still under construction! Not ready for use yet! Currently experimenting and planning!
Open-DIP is an open source python library for Digital Image Processing (DIP). This is an effort in progress! 

Developed by Akaawase Bernard (c) 2023
